# Resume Reader <br>
package which can retrieve skill sets and work experience from resume <br>


Need poppler and Tesseract install to the system <br>

poppler: <br>
  Windows: <br>
    https://blog.alivate.com.au/poppler-windows/  <br>
  Linux: <br>
    apt-get install poppler-utils <br>
   Mac:<br>
    brew install poppler<br>
  any: <br>
    update line: pages = convert_from_path(filepath, poppler_path=r"actualpoppler_path")<br>
    or <br>
    Install chocolatey https://chocolatey.org/install<br>
    then install poppler using choco: ```choco install poppler```<br>

Tesseract: https://github.com/UB-Mannheim/tesseract/wiki<br>



